@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -30,12 +30,10 @@ class WebViewSignals(WebViewMenuSignals, WebViewJsSignals,
     """
 
     gsignals = {
-        "readable": (GObject.SignalFlags.RUN_FIRST, None, ()),
+        "readability-content": (GObject.SignalFlags.RUN_FIRST, None, (str,)),
         "shown": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "title-changed": (GObject.SignalFlags.RUN_FIRST, None, (str,)),
         "uri-changed": (GObject.SignalFlags.RUN_FIRST, None, (str,)),
-        "favicon-changed": (GObject.SignalFlags.RUN_FIRST, None,
-                            (GObject.TYPE_PYOBJECT,)),
         "snapshot-changed": (GObject.SignalFlags.RUN_FIRST, None,
                              (GObject.TYPE_PYOBJECT,)),
     }
@@ -102,8 +100,11 @@ class WebViewSignals(WebViewMenuSignals, WebViewJsSignals,
         if self._window != self.get_toplevel():
             return
         # URI set but not loaded
-        if webview.get_uri() != webview.uri:
-            webview.load_uri(webview.uri)
+        # Webviews with a related webview have a None URI
+        if self.get_uri() is None and\
+                self.uri is not None and\
+                self._related_view is None:
+            self.load_uri(self.uri)
         self._shown = True
         self.emit("shown")
         self.set_atime(int(time()))
@@ -200,7 +201,8 @@ class WebViewSignals(WebViewMenuSignals, WebViewJsSignals,
         self.__title_changed_timeout_id = GLib.timeout_add(
             2000, title_changed_timeout)
         self.__cancellable.cancel()
-        self.__cancellable.reset()
+        self.__cancellable = Gio.Cancellable()
+        self._readable = False
 
     def __on_title_changed(self, webview, title):
         """
